WidgitUtils
===========

Widgit is a next-generation hosting platform tailored for mods, modding guides,
and guilds which is currently under active development. At present, our hosting
platform is in private beta, but we have several active Discord servers running
under our brand today!

Each of our Discord servers is managed by a networked instance of the awesome
[Red DiscordBot](https://github.com/Cog-Creators/Red-DiscordBot) which has been
extended through a series of custom cogs we built in-house. WidgitUtils is a
standardized library of common-use utilities thoughout our cogs.
